@@ -28,6 +28,7 @@
 #include "../../wrapper/ringbuffer/frontend.h"
 #include "../../wrapper/ringbuffer/vfs.h"
 #include "../../wrapper/poll.h"
+#include "../../lttng-tracer.h"
 
 static int put_ulong(unsigned long val, unsigned long arg)
 {
@@ -41,17 +42,13 @@ static int compat_put_ulong(compat_ulong_t val, unsigned long arg)
 }
 #endif
 
-/**
- *	lib_ring_buffer_open - ring buffer open file operation
- *	@inode: opened inode
- *	@file: opened file
- *
- *	Open implementation. Makes sure only one open instance of a buffer is
- *	done at a given moment.
+/*
+ * This is not used by anonymous file descriptors. This code is left
+ * there if we ever want to implement an inode with open() operation.
  */
-int lib_ring_buffer_open(struct inode *inode, struct file *file)
+int lib_ring_buffer_open(struct inode *inode, struct file *file,
+		struct lib_ring_buffer *buf)
 {
-	struct lib_ring_buffer *buf = inode->i_private;
 	int ret;
 
 	if (!buf)
@@ -61,7 +58,6 @@ int lib_ring_buffer_open(struct inode *inode, struct file *file)
 	if (ret)
 		return ret;
 
-	file->private_data = buf;
 	ret = nonseekable_open(inode, file);
 	if (ret)
 		goto release_read;
@@ -71,34 +67,53 @@ release_read:
 	lib_ring_buffer_release_read(buf);
 	return ret;
 }
+EXPORT_SYMBOL_GPL(lib_ring_buffer_open);
 
 /**
- *	lib_ring_buffer_release - ring buffer release file operation
+ *	vfs_lib_ring_buffer_open - ring buffer open file operation
+ *	@inode: opened inode
+ *	@file: opened file
+ *
+ *	Open implementation. Makes sure only one open instance of a buffer is
+ *	done at a given moment.
+ */
+static
+int vfs_lib_ring_buffer_open(struct inode *inode, struct file *file)
+{
+	struct lib_ring_buffer *buf = inode->i_private;
+
+	file->private_data = buf;
+	return lib_ring_buffer_open(inode, file, buf);
+}
+
+int lib_ring_buffer_release(struct inode *inode, struct file *file,
+		struct lib_ring_buffer *buf)
+{
+	lib_ring_buffer_release_read(buf);
+
+	return 0;
+}
+EXPORT_SYMBOL_GPL(lib_ring_buffer_release);
+
+/**
+ *	vfs_lib_ring_buffer_release - ring buffer release file operation
  *	@inode: opened inode
  *	@file: opened file
  *
  *	Release implementation.
  */
-int lib_ring_buffer_release(struct inode *inode, struct file *file)
+static
+int vfs_lib_ring_buffer_release(struct inode *inode, struct file *file)
 {
 	struct lib_ring_buffer *buf = file->private_data;
 
-	lib_ring_buffer_release_read(buf);
-
-	return 0;
+	return lib_ring_buffer_release(inode, file, buf);
 }
 
-/**
- *	lib_ring_buffer_poll - ring buffer poll file operation
- *	@filp: the file
- *	@wait: poll table
- *
- *	Poll implementation.
- */
-unsigned int lib_ring_buffer_poll(struct file *filp, poll_table *wait)
+unsigned int lib_ring_buffer_poll(struct file *filp, poll_table *wait,
+		struct lib_ring_buffer *buf)
 {
 	unsigned int mask = 0;
-	struct lib_ring_buffer *buf = filp->private_data;
 	struct channel *chan = buf->backend.chan;
 	const struct lib_ring_buffer_config *config = &chan->backend.config;
 	int finalized, disabled;
@@ -148,34 +163,26 @@ retry:
 	}
 	return mask;
 }
+EXPORT_SYMBOL_GPL(lib_ring_buffer_poll);
 
 /**
- *	lib_ring_buffer_ioctl - control ring buffer reader synchronization
- *
+ *	vfs_lib_ring_buffer_poll - ring buffer poll file operation
  *	@filp: the file
- *	@cmd: the command
- *	@arg: command arg
+ *	@wait: poll table
  *
- *	This ioctl implements commands necessary for producer/consumer
- *	and flight recorder reader interaction :
- *	RING_BUFFER_GET_NEXT_SUBBUF
- *		Get the next sub-buffer that can be read. It never blocks.
- *	RING_BUFFER_PUT_NEXT_SUBBUF
- *		Release the currently read sub-buffer.
- *	RING_BUFFER_GET_SUBBUF_SIZE
- *		returns the size of the current sub-buffer.
- *	RING_BUFFER_GET_MAX_SUBBUF_SIZE
- *		returns the maximum size for sub-buffers.
- *	RING_BUFFER_GET_NUM_SUBBUF
- *		returns the number of reader-visible sub-buffers in the per cpu
- *              channel (for mmap).
- *      RING_BUFFER_GET_MMAP_READ_OFFSET
- *              returns the offset of the subbuffer belonging to the reader.
- *              Should only be used for mmap clients.
+ *	Poll implementation.
  */
-long lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
+static
+unsigned int vfs_lib_ring_buffer_poll(struct file *filp, poll_table *wait)
 {
 	struct lib_ring_buffer *buf = filp->private_data;
+
+	return lib_ring_buffer_poll(filp, wait, buf);
+}
+
+long lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd,
+		unsigned long arg, struct lib_ring_buffer *buf)
+{
 	struct channel *chan = buf->backend.chan;
 	const struct lib_ring_buffer_config *config = &chan->backend.config;
 
@@ -261,18 +268,50 @@ long lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd, unsigned long ar
 				 arg);
 	}
 	case RING_BUFFER_FLUSH:
-		lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
+		lib_ring_buffer_switch_remote(buf);
 		return 0;
 	default:
 		return -ENOIOCTLCMD;
 	}
 }
+EXPORT_SYMBOL_GPL(lib_ring_buffer_ioctl);
+
+/**
+ *	vfs_lib_ring_buffer_ioctl - control ring buffer reader synchronization
+ *
+ *	@filp: the file
+ *	@cmd: the command
+ *	@arg: command arg
+ *
+ *	This ioctl implements commands necessary for producer/consumer
+ *	and flight recorder reader interaction :
+ *	RING_BUFFER_GET_NEXT_SUBBUF
+ *		Get the next sub-buffer that can be read. It never blocks.
+ *	RING_BUFFER_PUT_NEXT_SUBBUF
+ *		Release the currently read sub-buffer.
+ *	RING_BUFFER_GET_SUBBUF_SIZE
+ *		returns the size of the current sub-buffer.
+ *	RING_BUFFER_GET_MAX_SUBBUF_SIZE
+ *		returns the maximum size for sub-buffers.
+ *	RING_BUFFER_GET_NUM_SUBBUF
+ *		returns the number of reader-visible sub-buffers in the per cpu
+ *              channel (for mmap).
+ *      RING_BUFFER_GET_MMAP_READ_OFFSET
+ *              returns the offset of the subbuffer belonging to the reader.
+ *              Should only be used for mmap clients.
+ */
+static
+long vfs_lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
+{
+	struct lib_ring_buffer *buf = filp->private_data;
+
+	return lib_ring_buffer_ioctl(filp, cmd, arg, buf);
+}
 
 #ifdef CONFIG_COMPAT
 long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
-				  unsigned long arg)
+		unsigned long arg, struct lib_ring_buffer *buf)
 {
-	struct lib_ring_buffer *buf = filp->private_data;
 	struct channel *chan = buf->backend.chan;
 	const struct lib_ring_buffer_config *config = &chan->backend.config;
 
@@ -280,14 +319,14 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 		return -EIO;
 
 	switch (cmd) {
-	case RING_BUFFER_SNAPSHOT:
+	case RING_BUFFER_COMPAT_SNAPSHOT:
 		return lib_ring_buffer_snapshot(buf, &buf->cons_snapshot,
 						&buf->prod_snapshot);
-	case RING_BUFFER_SNAPSHOT_GET_CONSUMED:
+	case RING_BUFFER_COMPAT_SNAPSHOT_GET_CONSUMED:
 		return compat_put_ulong(buf->cons_snapshot, arg);
-	case RING_BUFFER_SNAPSHOT_GET_PRODUCED:
+	case RING_BUFFER_COMPAT_SNAPSHOT_GET_PRODUCED:
 		return compat_put_ulong(buf->prod_snapshot, arg);
-	case RING_BUFFER_GET_SUBBUF:
+	case RING_BUFFER_COMPAT_GET_SUBBUF:
 	{
 		__u32 uconsume;
 		unsigned long consume;
@@ -306,11 +345,11 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 		}
 		return ret;
 	}
-	case RING_BUFFER_PUT_SUBBUF:
+	case RING_BUFFER_COMPAT_PUT_SUBBUF:
 		lib_ring_buffer_put_subbuf(buf);
 		return 0;
 
-	case RING_BUFFER_GET_NEXT_SUBBUF:
+	case RING_BUFFER_COMPAT_GET_NEXT_SUBBUF:
 	{
 		long ret;
 
@@ -321,19 +360,19 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 		}
 		return ret;
 	}
-	case RING_BUFFER_PUT_NEXT_SUBBUF:
+	case RING_BUFFER_COMPAT_PUT_NEXT_SUBBUF:
 		lib_ring_buffer_put_next_subbuf(buf);
 		return 0;
-	case RING_BUFFER_GET_SUBBUF_SIZE:
+	case RING_BUFFER_COMPAT_GET_SUBBUF_SIZE:
 	{
 		unsigned long data_size;
 
 		data_size = lib_ring_buffer_get_read_data_size(config, buf);
 		if (data_size > UINT_MAX)
 			return -EFBIG;
-		return put_ulong(data_size, arg);
+		return compat_put_ulong(data_size, arg);
 	}
-	case RING_BUFFER_GET_PADDED_SUBBUF_SIZE:
+	case RING_BUFFER_COMPAT_GET_PADDED_SUBBUF_SIZE:
 	{
 		unsigned long size;
 
@@ -341,13 +380,13 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 		size = PAGE_ALIGN(size);
 		if (size > UINT_MAX)
 			return -EFBIG;
-		return put_ulong(size, arg);
+		return compat_put_ulong(size, arg);
 	}
-	case RING_BUFFER_GET_MAX_SUBBUF_SIZE:
+	case RING_BUFFER_COMPAT_GET_MAX_SUBBUF_SIZE:
 		if (chan->backend.subbuf_size > UINT_MAX)
 			return -EFBIG;
-		return put_ulong(chan->backend.subbuf_size, arg);
-	case RING_BUFFER_GET_MMAP_LEN:
+		return compat_put_ulong(chan->backend.subbuf_size, arg);
+	case RING_BUFFER_COMPAT_GET_MMAP_LEN:
 	{
 		unsigned long mmap_buf_len;
 
@@ -358,9 +397,9 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 			mmap_buf_len += chan->backend.subbuf_size;
 		if (mmap_buf_len > UINT_MAX)
 			return -EFBIG;
-		return put_ulong(mmap_buf_len, arg);
+		return compat_put_ulong(mmap_buf_len, arg);
 	}
-	case RING_BUFFER_GET_MMAP_READ_OFFSET:
+	case RING_BUFFER_COMPAT_GET_MMAP_READ_OFFSET:
 	{
 		unsigned long sb_bindex, read_offset;
 
@@ -371,28 +410,38 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 		read_offset = buf->backend.array[sb_bindex]->mmap_offset;
 		if (read_offset > UINT_MAX)
 			return -EINVAL;
-		return put_ulong(read_offset, arg);
+		return compat_put_ulong(read_offset, arg);
 	}
-	case RING_BUFFER_FLUSH:
-		lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
+	case RING_BUFFER_COMPAT_FLUSH:
+		lib_ring_buffer_switch_remote(buf);
 		return 0;
 	default:
 		return -ENOIOCTLCMD;
 	}
 }
+EXPORT_SYMBOL_GPL(lib_ring_buffer_compat_ioctl);
+
+static
+long vfs_lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
+				  unsigned long arg)
+{
+	struct lib_ring_buffer *buf = filp->private_data;
+
+	return lib_ring_buffer_compat_ioctl(filp, cmd, arg, buf);
+}
 #endif
 
 const struct file_operations lib_ring_buffer_file_operations = {
 	.owner = THIS_MODULE,
-	.open = lib_ring_buffer_open,
-	.release = lib_ring_buffer_release,
-	.poll = lib_ring_buffer_poll,
-	.splice_read = lib_ring_buffer_splice_read,
-	.mmap = lib_ring_buffer_mmap,
-	.unlocked_ioctl = lib_ring_buffer_ioctl,
-	.llseek = lib_ring_buffer_no_llseek,
+	.open = vfs_lib_ring_buffer_open,
+	.release = vfs_lib_ring_buffer_release,
+	.poll = vfs_lib_ring_buffer_poll,
+	.splice_read = vfs_lib_ring_buffer_splice_read,
+	.mmap = vfs_lib_ring_buffer_mmap,
+	.unlocked_ioctl = vfs_lib_ring_buffer_ioctl,
+	.llseek = vfs_lib_ring_buffer_no_llseek,
 #ifdef CONFIG_COMPAT
-	.compat_ioctl = lib_ring_buffer_compat_ioctl,
+	.compat_ioctl = vfs_lib_ring_buffer_compat_ioctl,
 #endif
 };
 EXPORT_SYMBOL_GPL(lib_ring_buffer_file_operations);
@@ -400,3 +449,7 @@ EXPORT_SYMBOL_GPL(lib_ring_buffer_file_operations);
 MODULE_LICENSE("GPL and additional rights");
 MODULE_AUTHOR("Mathieu Desnoyers");
 MODULE_DESCRIPTION("Ring Buffer Library VFS");
+MODULE_VERSION(__stringify(LTTNG_MODULES_MAJOR_VERSION) "."
+	__stringify(LTTNG_MODULES_MINOR_VERSION) "."
+	__stringify(LTTNG_MODULES_PATCHLEVEL_VERSION)
+	LTTNG_MODULES_EXTRAVERSION);
